@@ -440,8 +440,11 @@ char *EncodePhonemes(char *p, char *outptr, unsigned char *bad_phoneme)
 			{
 				// Switch Language: this phoneme is followed by a text string
 				char *p_lang = outptr;
-				while(!isspace(c = *p++) && (c != 0))
+				while(!isspace(c = *p) && (c != 0))
+				{
+					p++;
 					*outptr++ = tolower(c);
+				}
 				*outptr = 0;
 				if(c == 0)
 				{
@@ -1170,7 +1173,16 @@ void Translator::SetWordStress(char *output, unsigned int dictionary_flags, int
 			stressed_syllable = vowel_count - 1;
 			if(max_stress == 0)
 			{
-				vowel_stress[stressed_syllable] = 4;
+				while(stressed_syllable > 0)
+				{
+					if(vowel_stress[stressed_syllable] == 0)
+					{
+						vowel_stress[stressed_syllable] = 4;
+						break;
+					}
+					else
+						stressed_syllable--;
+				}
 			}
 			max_stress = 4;
 		}
