@@ -1747,14 +1747,21 @@ static int ProcessSsmlTag(wchar_t *xml_buf, char *outbuf, int &outix, int n_outb
 		return(CLAUSE_VOICE);
 
 	case SSML_SPEAK + SSML_CLOSE:
-		terminator = CLAUSE_PERIOD;
+		// unwind stack until the previous <voice> or <speak> tag
+		while((n_ssml_stack > 1) && (ssml_stack[n_ssml_stack-1].tag_type != SSML_SPEAK))
+		{
+			n_ssml_stack--;
+		}
+		return(CLAUSE_PERIOD + GetVoiceAttributes(px, tag_type));
+
 	case SSML_VOICE + SSML_CLOSE:
 		// unwind stack until the previous <voice> or <speak> tag
-		while((n_ssml_stack > 1) && (ssml_stack[n_ssml_stack-1].tag_type != (tag_type - SSML_CLOSE)))
+		while((n_ssml_stack > 1) && (ssml_stack[n_ssml_stack-1].tag_type != SSML_VOICE))
 		{
 			n_ssml_stack--;
 		}
 
+terminator=0;  // ??  Sentence intonation, but no pause ??
 		return(terminator + GetVoiceAttributes(px, tag_type));
 
 	case HTML_BREAK:
@@ -1818,8 +1825,8 @@ MNEM_TAB xml_char_mnemonics[] = {
 	{NULL,-1}};
 
 
-int Translator::ReadClause(FILE *f_in, char *buf, unsigned short *charix, int n_buf)
-{//=================================================================================
+int Translator::ReadClause(FILE *f_in, char *buf, short *charix, int n_buf)
+{//========================================================================
 /* Find the end of the current clause.
 	Write the clause into  buf
 
@@ -2274,7 +2281,7 @@ if(option_ssml) parag=1;
 		{
 			charix[ix] = count_characters - clause_start_char;
 			while(j < ix)
-				charix[j++] = 0xffff;   // subsequent bytes of a multibyte character
+				charix[j++] = -1;   // subsequent bytes of a multibyte character
 		}
 
 		if(((ix > (n_buf-20)) && !IsAlpha(c1) && !iswdigit(c1))  ||  (ix >= (n_buf-2)))
