@@ -373,6 +373,9 @@ int IsAlpha(unsigned int c)
 	if((c >= 0x1100) && (c <= 0x11ff))
 		return(1);  //Korean jamo
 
+	if((c > 0x3040) && (c <= 0xa700))
+		return(1); // Chinese/Japanese.  Should never get here, but Mac OS 10.4's iswalpha seems to be broken, so just make sure
+
 	return(0);
 }
 
@@ -396,6 +399,8 @@ int IsDigit(unsigned int c)
 
 int IsSpace(unsigned int c)
 {//========================
+	if(c == 0)
+		return(0);
 	if(wcschr(chars_space,c))
 		return(1);
 	return(iswspace(c));
@@ -2010,7 +2015,7 @@ void *Translator::TranslateClause(FILE *f_text, const void *vp_input, int *tone_
 	int j, k;
 	int n_digits;
 
-	unsigned short charix[N_TR_SOURCE+1];
+	short charix[N_TR_SOURCE+1];
 
 	WORD_TAB words[N_CLAUSE_WORDS];
 	int word_count=0;      // index into words
@@ -2106,7 +2111,7 @@ void *Translator::TranslateClause(FILE *f_text, const void *vp_input, int *tone_
 	while(charix[j] != 0)
 	{
 		// count the number of characters (excluding multibyte continuation bytes)
-		if(charix[j++] != 0xffff)
+		if(charix[j++] != -1)
 			k++;
 	}
 	words[0].length = k;
@@ -2511,13 +2516,13 @@ if((c == '/') && (langopts.testing & 2) && IsDigit09(next_in) && IsAlpha(prev_ou
 				words[word_count].start = ix;
 				words[word_count].flags = 0;
 
-				for(j=source_index; charix[j] == 0; j++);   // skip blanks
+				for(j=source_index; charix[j] <= 0; j++);   // skip blanks
 				words[word_count].sourceix = charix[j];
 				k = 0;
 				while(charix[j] != 0)
 				{
 					// count the number of characters (excluding multibyte continuation bytes)
-					if(charix[j++] != 0xffff)
+					if(charix[j++] != -1)
 						k++;
 				}
 				words[word_count].length = k;
